summaryrefslogtreecommitdiff
path: root/worker/tests/rsync.rb
diff options
context:
space:
mode:
Diffstat (limited to 'worker/tests/rsync.rb')
-rwxr-xr-xworker/tests/rsync.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/worker/tests/rsync.rb b/worker/tests/rsync.rb
index e410454..1d4e49f 100755
--- a/worker/tests/rsync.rb
+++ b/worker/tests/rsync.rb
@@ -39,7 +39,7 @@ class RSYNCTest
#
# Return "false" on failure.
#
# If the test fails the details should be retrieved from "get_details".
#
def run_test
@error = ""
@@ -90,7 +90,7 @@ class RSYNCTest
#
# Return the error text for why this test failed.
#
- def get_details
+ def error
return @error
end
@@ -121,7 +121,7 @@ if __FILE__ == $0 then
puts "TEST OK"
else
puts "TEST FAILED"
- puts obj.get_details()
+ puts obj.error()
end
end
@@ -39,7 +39,7 @@ class RSYNCTest
# Return "false" on failure.
#
- # If the test fails the details should be retrieved from "get_details".
+ # If the test fails the details should be retrieved from "error()".
#
def run_test